SystemOrganization addCategory: #'Magritte-RowRenderer'!

MAComponentRenderer subclass: #MARowRenderer
	instanceVariableNames: 'rows columnspan columns'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-RowRenderer'!

!MARowRenderer commentStamp: 'jmck 6/22/2009 22:32' prior: 0!
I am a component renderer that will layout the component controls of my model object in a horizontal fashion based on description priorities (modulo 10). E.g. descriptions with priority 0-9 will render on a single row, 10-19 on the next row and so on. Labels will be rendered above the control.
Any row that has only one description will have a columnspan attribute applied so that it will span the columns of the table (this is useful for MAToManyRelationDescriptions).!

!MARowRenderer methodsFor: 'rendering' stamp: 'jmck 7/15/2009 14:21'!
renderContainer: aDescription
	| description rowcount | 
	description := aDescription select: [ :each | each isVisible ].
	rowcount := description children last priority // 10.
	
	rows := OrderedCollection ofSize: 0.
	(0 to: rowcount) do: [ :row | | coll |
		(coll := description select: [ :each | each priority // 10 = row ]) size > 0 
			ifTrue: [ rows add: coll ] ].
	
	columns := rows inject: 0 into: [ :cols :row | cols max: row children size  ].
	
	html table
		class: (self classFor: aDescription);
		with: [
			rows do: [ :each | self renderRow: each ]]
	
	! !

!MARowRenderer methodsFor: 'rendering' stamp: 'jmck 7/15/2009 14:18'!
renderRow: aCollection
	html tableRow: [ self renderRowLabels: aCollection ].
	html tableRow: [ self renderRowValues: aCollection ].
! !

!MARowRenderer methodsFor: 'rendering' stamp: 'jmck 6/28/2009 16:54'!
renderRowLabels: aCollection
	aCollection do: [ :each | 
			html tableData: [ html label: each label ] ] ! !

!MARowRenderer methodsFor: 'rendering' stamp: 'jmck 7/15/2009 14:19'!
renderRowValues: aCollection
	| span |
	span := columns // aCollection size.
	aCollection do: [ :each | 
		html tableData colSpan: span; with: [ super renderControl: each ] ]
	"aCollection do: [ :each | (each isEmbeddedCollection or: [aCollection size = 1])
		ifTrue: [ html tableData colSpan: columnspan; with: [ super renderControl: each ] ]
		ifFalse: [ html tableData: [ super renderControl: each ] ] ]"! !

MAPriorityContainer subclass: #MARowContainer
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-RowRenderer'!

!MARowContainer commentStamp: 'jmck 6/22/2009 22:24' prior: 0!
I am a priority container that defaults to using MARowRender to render the controls of my described model
To get MARowRenderer functionality implement class>>descriptionContainer to return my class on your model object!

!MARowContainer class methodsFor: 'defaults' stamp: 'jmck 6/22/2009 22:39'!
defaultComponentRenderer
	^MARowRenderer! !
